@@ -165,9 +165,9 @@ void ccp4_CtoFString(fpstr str1, int str1_len, const char *cstring)
 /* <ustenv code>=                                                           */
 #if ! defined (VMS)
 FORTRAN_SUBR ( USTENV, ustenv,
-         (fpstr str, int *result, int str_len),
+         (fpstr str, int *result, fpstr_size_t str_len),
          (fpstr str, int *result),
-         (fpstr str, int str_len, int *result))
+         (fpstr str, fpstr_size_t str_len, int *result))
 {
   char *temp_name;
 
@@ -179,7 +179,6 @@ FORTRAN_SUBR ( USTENV, ustenv,
 }
 #endif
 
-#if ! defined (_MSC_VER)
 FORTRAN_SUBR ( USTIME, ustime,
          (int *isec),
          (int *isec),
@@ -187,7 +186,6 @@ FORTRAN_SUBR ( USTIME, ustime,
 {
   *isec = time(NULL);
 }
-#endif
 
 /* \section{Miscellaneous routines}                                         */
 /* \subsection{{\tt outbuf()}}                                              */
@@ -216,9 +214,9 @@ FORTRAN_SUBR ( OUTBUF, outbuf, (), (), ())
 /*                                                                          */
 /* <miscellaneous routines>=                                                */
 FORTRAN_SUBR ( CUNLINK, cunlink,
-      (fpstr filename, int filename_len),
+      (fpstr filename, fpstr_size_t filename_len),
       (fpstr filename),
-      (fpstr filename, int filename_len))
+      (fpstr filename, fpstr_size_t filename_len))
 {
 #ifdef VMS
   return;                       /* can't do it */
@@ -267,7 +265,6 @@ FORTRAN_SUBR ( CUNLINK, cunlink,
 /*                                                                          */
 /* <miscellaneous routines>=                                                */
 #ifndef VMS                     /* we'll use the Fortran version in VMS*/
-#ifndef _MSC_VER
 FORTRAN_SUBR ( CCPAL1, ccpal1,
      (void (* routne) (), int *n, int type[], int length[]),
      (void (* routne) (), int *n, int type[], int length[]),
@@ -376,7 +373,6 @@ FORTRAN_SUBR ( CCPAL1, ccpal1,
     free (pointer[i+1]);
 }
 #endif /* VMS */
-#endif
 
 /* \section{`Magic' numbers}                                                */
 /*                                                                          */
@@ -502,9 +498,9 @@ FORTRAN_SUBR ( HGETLIMITS, hgetlimits,
 /* Wrap-around for mkdir function. Returns 0 if successful, 1 if directory  */
 /* already exists, and -1 if other error.                                   */
 FORTRAN_SUBR ( CMKDIR, cmkdir,
-    (const fpstr path, const fpstr cmode, int *result, int path_len, int cmode_len),
+    (const fpstr path, const fpstr cmode, int *result, fpstr_size_t path_len, fpstr_size_t cmode_len),
     (const fpstr path, const fpstr cmode, int *result),
-    (const fpstr path, int path_len, const fpstr cmode, int cmode_len, int *result))
+    (const fpstr path, fpstr_size_t path_len, const fpstr cmode, fpstr_size_t cmode_len, int *result))
 { 
   char *temp_path, *temp_cmode;
 
@@ -519,9 +515,9 @@ FORTRAN_SUBR ( CMKDIR, cmkdir,
 /* Wrap-around for mkdir function. Returns 0 if successful, 1 if directory     */
 /* already exists, and -1 if other error.                                      */
 FORTRAN_SUBR ( CCHMOD, cchmod,
-    (const fpstr path, const fpstr cmode, int *result, int path_len, int cmode_len),
+    (const fpstr path, const fpstr cmode, int *result, fpstr_size_t path_len, fpstr_size_t cmode_len),
     (const fpstr path, const fpstr cmode, int *result),
-    (const fpstr path, int path_len, const fpstr cmode, int cmode_len, int *result))
+    (const fpstr path, fpstr_size_t path_len, const fpstr cmode, fpstr_size_t cmode_len, int *result))
 { 
   char *temp_path, *temp_cmode;
 
@@ -700,7 +696,7 @@ int ierrno () {
 
 #endif             /*  HPUX and AIX support */    
 
-#if !( defined(G95) || defined(GFORTRAN) || defined(F2C) ) && \
+#if !( defined(G95) || defined(GFORTRAN) || defined(F2C) || defined(__INTEL_COMPILER) ) && \
     ( ( defined(__linux__) && defined(_CALL_SYSV) ) || defined(__APPLE__) )
 /* linuxppc xlf and apple xlf support */
 void gerror_ (str, Lstr)
